@@ -1,5 +1,7 @@
 package WWW::SmartSheet::Sheet;
-$WWW::SmartSheet::Sheet::VERSION = '0.03';
+
+our $VERSION = '0.04';
+
 use Moo;
 use MooX::late;
 
@@ -19,11 +21,11 @@ __END__
 
 =head1 NAME
 
-WWW::SmartSheet::Sheet
+WWW::SmartSheet::Sheet - Represent 'sheet' object.
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
